@@ -94,6 +94,7 @@ class MINTCompiler(mintListener):
 
     def enterWidthParam(self, ctx: mintParser.WidthParamContext):
         value = ctx.value().getText()
+        assert ctx.key is not None
         key = ctx.key.text
         if key is None:
             raise Exception("Error in parsing the width parameter")
@@ -106,6 +107,10 @@ class MINTCompiler(mintListener):
         self.current_entity = None
         self.current_params = dict()
 
+    def enterControlStat(self, ctx: mintParser.ControlStatContext):
+        self.current_entity = None
+        self.current_params = dict()
+
     def exitPrimitiveStat(self, ctx: mintParser.PrimitiveStatContext):
         entity = self.current_entity
         if entity is None:
@@ -115,13 +120,14 @@ class MINTCompiler(mintListener):
         for ufname in ctx.ufnames().ufname():
             if self._current_layer is None:
                 raise Exception("Current layer is set to None")
+            assert (
+                self._current_layer is not None and self._current_layer.ID is not None
+            )
             self.current_device.create_mint_component(
                 ufname.getText(),
                 entity,
                 self.current_params,
-                [
-                    self._current_layer.ID,
-                ],
+                [self._current_layer.ID],
             )
 
     def exitBankDeclStat(self, ctx: mintParser.BankDeclStatContext):
@@ -134,6 +140,7 @@ class MINTCompiler(mintListener):
 
         for ufname in ctx.ufnames().ufname():
             component_name = ufname.getText()
+            assert self._current_layer.ID is not None
             self.current_device.create_mint_component(
                 component_name,
                 entity,
@@ -148,6 +155,7 @@ class MINTCompiler(mintListener):
 
         self._cleanup_BANK_params()
 
+        assert ctx.dim is not None
         dim = int(ctx.dim.text)
 
         name = ctx.ufname().getText()
@@ -156,11 +164,11 @@ class MINTCompiler(mintListener):
             component_name = name + "_" + str(i)
             if self._current_layer is None:
                 raise Exception("Current Layer not Set")
+            assert (
+                self._current_layer is not None and self._current_layer.ID is not None
+            )
             self.current_device.create_mint_component(
-                component_name,
-                entity,
-                self.current_params,
-                [self._current_layer.ID],
+                component_name, entity, self.current_params, [self._current_layer.ID]
             )
 
     def exitGridDeclStat(self, ctx: mintParser.GridDeclStatContext):
@@ -172,6 +180,7 @@ class MINTCompiler(mintListener):
 
         for ufname in ctx.ufnames().ufname():
             component_name = ufname.getText()
+            assert self._current_layer.ID is not None
             self.current_device.create_mint_component(
                 component_name,
                 entity,
@@ -218,6 +227,7 @@ class MINTCompiler(mintListener):
         self._cleanup_CHANNEL_params()
 
         # Create a connection between the different components in the device
+        assert self._current_layer is not None and self._current_layer.ID is not None
         self.current_device.create_mint_connection(
             connection_name,
             entity,
@@ -253,7 +263,7 @@ class MINTCompiler(mintListener):
                 sink_port = None
 
             sink_uftargets.append(MINTTarget(sink_id, sink_port))
-
+        assert self._current_layer is not None and self._current_layer.ID is not None
         self.current_device.create_mint_connection(
             connection_name,
             entity,
@@ -278,6 +288,7 @@ class MINTCompiler(mintListener):
 
         # Loop for each of the components that need to be created with this param
         for ufname in ctx.ufnames().ufname():
+            assert self._current_layer.ID is not None
             self.current_device.create_mint_component(
                 ufname.getText(),
                 entity,
@@ -289,6 +300,7 @@ class MINTCompiler(mintListener):
         entity = "NODE"
 
         # Loop for each of the components that need to be created with this param
+        assert self._current_layer is not None and self._current_layer.ID is not None
         for ufname in ctx.ufnames().ufname():
             self.current_device.create_mint_component(
                 ufname.getText(),
@@ -303,6 +315,7 @@ class MINTCompiler(mintListener):
             logging.error("Could not find entitry information for valve")
             raise Exception("Could not find entitry information for valve")
         valve_name = ctx.ufname()[0].getText()
+        assert self._current_layer is not None and self._current_layer.ID is not None
         valve_component = self.current_device.create_mint_component(
             valve_name,
             entity,
@@ -329,10 +342,11 @@ class MINTCompiler(mintListener):
     def enterTerminalStat(self, ctx: mintParser.TerminalStatContext):
         terminal_name = ctx.ufname().getText()
         pin_number = int(ctx.INT.getText())
+        assert self._current_layer is not None and self._current_layer.ID is not None
         self.current_device.add_terminal(
             terminal_name,
             pin_number,
-            self._current_layer,
+            self._current_layer.ID,
         )
 
     def exitNetlist(self, ctx: mintParser.NetlistContext):
