@@ -7,18 +7,26 @@ from pymint.mintlayer import MINTLayer, MINTLayerType
 from parchmint.device import Device
 from pymint.mintcomponent import MINTComponent
 from pymint.mintconnection import MINTConnection
-from typing import List, Optional
+from typing import List
 import sys
 
 
 class MINTDevice(Device):
-    def __init__(self, name: str) -> None:
-        super().__init__()
+    def __init__(self, name: str, json=None) -> None:
         """Creates a MINT device
+
+        A MINT device has the extra bells and whistles necessary for genrating
+        structured MINT. Pass the ParchMINT JSON to the `json` arg if you want
+        to initialize from a JSON file.
+
+        Args:
+            name (str): name of the device
+            json (str, optional): JSON string. Defaults to None.
         """
+        super(MINTDevice, self).__init__(json=json)
+
         self.name = name
         self._layout_constraints = []
-        self._valve_map = dict()
         self._terminals = []
         self._vias = []
 
@@ -72,6 +80,7 @@ class MINTDevice(Device):
         layer = super().get_layer(layer_id)
         if layer is None:
             raise Exception("Cannot create new MINT connection with invalid layer")
+        assert layer is not None
         connection = MINTConnection(name, technology, params, source, sinks, layer)
         super().add_connection(connection)
         return connection
@@ -145,17 +154,18 @@ class MINTDevice(Device):
         """
         self._valve_map[valve] = connection
 
-    def add_terminal(self, name: str, pin_number: int, layer: str) -> MINTTerminal:
+    def add_terminal(self, name: str, pin_number: int, layer_id: str) -> MINTTerminal:
         """Creates and adds a terminal to the device with an associated pin number
 
         Args:
             name (str): name of the pin
             pin_number (int): pin number of the terminal
-            layer (str): layer associated with the terminal
+            layer (str): layerid associated with the terminal
 
         Returns:
             MINTTerminal: The newly created terminal
         """
+        layer = self.get_layer(layer_id)
         ret = MINTTerminal(name, pin_number, layer)
         self._terminals.append(ret)
         self.components.append(ret)
@@ -239,6 +249,9 @@ class MINTDevice(Device):
 
         walker.walk(listener, tree)
 
+        assert listener.current_device is not None
+        current_device = listener.current_device
+
         if skip_constraints is not True:
             print("Computing Constraints")
             constraint_listener = ConstraintListener(listener.current_device)
