@@ -4,7 +4,7 @@ from parchmint.target import Target
 
 class MINTTarget(Target):
     def __init__(self, componentstring: str, portstring: Optional[str] = None) -> None:
-        super().__init__(None)
+        super(MINTTarget, self).__init__(None)
         self.component = componentstring
         self.port = portstring
 
